<?php

namespace Drupal\languagewire_translation_provider\Test\Builder\ClientLibrary;

use Drupal\languagewire_translation_provider\api\Project;
use Drupal\languagewire_translation_provider\api\Project\Assignment;
use Drupal\languagewire_translation_provider\api\Project\ProjectStatus;

/**
 * Project Builder .
 */
class ProjectBuilder {
  /**
   * Correlation Id .
   *
   * @var string Correlation Id
   */
  private $correlationId = 'uuid';

  /**
   * Title .
   *
   * @var string Title
   */
  private $title = 'Foo';

  /**
   * Platform Id .
   *
   * @var int Platform Id
   */
  private $platformId = 1;

  /**
   * Platform Url .
   *
   * @var string Platform Url
   */
  private $platformUrl = 'https://example.com/project/1';

  /**
   * Status .
   *
   * @var string Status
   */
  private $status = ProjectStatus::ACTIVE;

  /**
   * Assignments .
   *
   * @var array Assignments
   */
  private $assignments = [];

  /**
   * With Correlation Id .
   */
  public function withAssignment(Assignment $assignment): self {
    $this->assignments[] = $assignment;
    return $this;
  }

  /**
   * Build .
   */
  public function build(): Project {
    if (empty($this->assignments)) {
      $this->assignments[] = $this->getAssignment();
    }

    return new Project(
          $this->correlationId,
          $this->title,
          $this->platformId,
          $this->platformUrl,
          $this->status,
          $this->assignments
      );
  }

  /**
   * Get Assignment .
   */
  private function getAssignment(): Assignment {
    return (new AssignmentBuilder())->build();
  }

}
