<?php

namespace Drupal\languagewire_translation_provider\Test\Client;

use Drupal\languagewire_translation_provider\Adapter\TMGMT\LanguageMapping;
use Drupal\languagewire_translation_provider\api\Project\ProjectSpecification;
use Drupal\languagewire_translation_provider\api\Project\ProjectSpecificationInterface;
use Drupal\languagewire_translation_provider\Client\ClientInterface;
use Drupal\languagewire_translation_provider\Client\LanguageWireProjectSpecification;
use Drupal\languagewire_translation_provider\Client\Product;
use Drupal\languagewire_translation_provider\Platform\Document\ValidDocument;
use Drupal\languagewire_translation_provider\Platform\Services\ServiceInterface;
use Drupal\languagewire_translation_provider\Test\Builder\LanguageMappingBuilder;
use Drupal\languagewire_translation_provider\Test\Builder\ServiceBuilder;
use Drupal\languagewire_translation_provider\Test\Builder\ValidDocumentBuilder;
use PHPUnit\Framework\TestCase;

/**
 * LanguageWire Project Specification Test .
 */
class LanguageWireProjectSpecificationTest extends TestCase {
  use \Prophecy\PhpUnit\ProphecyTrait;

  /**
   * Client .
   *
   * @var \Prophecy\Prophecy\ObjectProphecy
   */
  protected $client;

  /**
   * Set Up .
   */
  protected function setUp(): void {
    $this->client = $this->prophesize(ClientInterface::class);
  }

  /**
   * It Creates Project Specification .
   *
   * @test
   */
  public function itCreatesProjectSpecification(): void {
    $service = (new ServiceBuilder())->build();
    $validDocument = (new ValidDocumentBuilder())->build();
    $language = (new LanguageMappingBuilder())->build();
    $projectUuid = 'uuid';
    $title = 'Foo';
    $briefing = 'Briefing';
    $platformProjectSpecs = new LanguageWireProjectSpecification([$validDocument->platformId()], $language, $projectUuid, $title, $service, $briefing);

    $platformProjectSpecs = $platformProjectSpecs->toSpecification($this->client->reveal());

    $this->assertProjectSpecification($title, $platformProjectSpecs, $briefing, $validDocument, $language, $service);
    $this->assertSame($service->id(), $platformProjectSpecs->getProduct());
    $this->assertEquals($service->deadline()->toUtc()->format(ProjectSpecificationInterface::DEADLINE_FORMAT), $platformProjectSpecs->getDeadline());
    $this->assertFalse($platformProjectSpecs->isDemo());
  }

  /**
   * It Creates Demo Project Specification .
   *
   * @test
   */
  public function itCreatesDemoProjectSpecification(): void {
    $service = (new ServiceBuilder())->buildDemoTranslation();
    $validDocument = (new ValidDocumentBuilder())->build();
    $language = (new LanguageMappingBuilder())->build();
    $projectUuid = 'uuid';
    $title = 'Foo';
    $briefing = 'Briefing';
    $product = new Product(1, 'Translation');
    $this->client->getProducts()->willReturn([$product]);
    $platformProjectSpecs = new LanguageWireProjectSpecification([$validDocument->platformId()], $language, $projectUuid, $title, $service, $briefing);

    $platformProjectSpecs = $platformProjectSpecs->toSpecification($this->client->reveal());

    $this->assertProjectSpecification($title, $platformProjectSpecs, $briefing, $validDocument, $language, $service);
    $this->assertSame($product->id(), $platformProjectSpecs->getProduct());
    $this->assertTrue($platformProjectSpecs->isDemo());
    $this->assertEquals($service->deadline()->toUtc()->format(ProjectSpecificationInterface::DEADLINE_FORMAT), $platformProjectSpecs->getDeadline());
  }

  /**
   * It Tests Project Specification .
   */
  private function assertProjectSpecification(string $title, ProjectSpecification $platformProjectSpecs, string $briefing, ValidDocument $validDocument, LanguageMapping $language, ServiceInterface $service): void {
    $this->assertSame($title, $platformProjectSpecs->getTitle());
    $this->assertNotNull($platformProjectSpecs->getCorrelationId());
    $this->assertSame($briefing, $platformProjectSpecs->getBriefing());

    $this->assertEquals([$validDocument->platformId()], $platformProjectSpecs->getSourceDocuments());

    $this->assertEquals([$language->remoteLanguage()], $platformProjectSpecs->getTargetLanguages());
    $this->assertSame($service->workAreaId(), $platformProjectSpecs->getWorkArea());
    $this->assertSame($service->translationMemoryId(), $platformProjectSpecs->getTranslationMemory());
    $this->assertSame($service->invoicingAccountId(), $platformProjectSpecs->getInvoicingAccount());
  }

}
