<?php

namespace Drupal\languagewire_translation_provider\Test\Platform\Document;

use Drupal\languagewire_translation_provider\api\Repository\Validation\Exception\InvalidAuthorizationKeyException;
use Drupal\languagewire_translation_provider\api\Repository\Validation\Exception\NotFoundException;
use Drupal\languagewire_translation_provider\api\Service\Exception\DocumentContentTooBigException;
use Drupal\languagewire_translation_provider\Platform\Document\InvalidDocument;
use Drupal\languagewire_translation_provider\Test\Builder\Domain\DocumentBuilder;
use PHPUnit\Framework\TestCase;

/**
 * Invalid Document Test .
 */
class InvalidDocumentTest extends TestCase {

  /**
   * When Creating From Upload Exception Then Creates New Instance Is Made .
   *
   * @test
   * @dataProvider uploadExceptionDataProvider
   */
  public function whenCreatingFromUploadExceptionThenCreatesNewInstanceIsMade(\Exception $exception, string $expectedMessage) {
    $domainDocument = (new DocumentBuilder())->build();
    $document = InvalidDocument::fromUploadException($exception, $domainDocument);

    $this->assertInstanceOf(InvalidDocument::class, $document);
    $this->assertEquals($domainDocument, $document->getDocument());

    $expectedReason = sprintf($expectedMessage, $domainDocument->getTitle());
    $this->assertSame($expectedReason, $document->getReason());
  }

  /**
   * When Creating From Requesting Then New Instance Is Made .
   *
   * @test
   * @dataProvider requestValidationExceptionDataProvider
   */
  public function whenCreatingFromRequestingValidationExceptionThenCreatesNewInstanceIsMade(\Exception $exception, string $expectedMessage) {
    $domainDocument = (new DocumentBuilder())->build();
    $document = InvalidDocument::fromRequestingValidationException($exception, $domainDocument);

    $this->assertInstanceOf(InvalidDocument::class, $document);
    $this->assertEquals($domainDocument, $document->getDocument());

    $expectedReason = sprintf($expectedMessage, $domainDocument->getTitle());
    $this->assertSame($expectedReason, $document->getReason());
  }

  /**
   * Upload Exception Data Provider .
   */
  public function uploadExceptionDataProvider(): array {
    return [
          [
            new DocumentContentTooBigException(''),
            'Contents of "%s" item are too big. LanguageWire accepts content up to 10GB in size.',
          ],
          [
            new InvalidAuthorizationKeyException(''),
            'Cannot upload "%s" item to the LanguageWire platform, because the API Key was rejected by the platform.',
          ],
          [
            new \Exception(''),
            'Could not upload "%s" item to LanguageWire platform.',
          ],
    ];
  }

  /**
   * Request Validation Exception Data Provider .
   */
  public function requestValidationExceptionDataProvider(): array {
    return [
          [
            new NotFoundException(''),
            'Item "%s" not found in the LanguageWire platform.',
          ],
          [
            new InvalidAuthorizationKeyException(''),
            'Cannot validate "%s" item at the LanguageWire platform, because the API Key was rejected by the platform.',
          ],
          [
            new \Exception(''),
            'Could not start item validation "%s" at the LanguageWire platform.',
          ],
    ];
  }

}
